@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "templatemanager.h"
@@ -104,14 +92,14 @@ void TemplateManager::loadTemplates(bool init)
 TemplateInfo TemplateManager::loadTemplate(const QString &themePath, const QString &defaultDesktopFileName)
 {
     TemplateInfo info;
-    const QString themeInfoFile = themePath + QDir::separator() + defaultDesktopFileName;
+    const QString themeInfoFile = themePath + QLatin1Char('/') + defaultDesktopFileName;
     KConfig config(themeInfoFile);
     KConfigGroup group(&config, QStringLiteral("Desktop Entry"));
 
     info.name = group.readEntry("Name", QString());
     const QString filename = group.readEntry("FileName", QString());
     if (!filename.isEmpty()) {
-        QFile file(themePath + QDir::separator() + filename);
+        QFile file(themePath + QLatin1Char('/') + filename);
         if (file.exists()) {
             if (file.open(QIODevice::ReadOnly)) {
                 info.script = QString::fromUtf8(file.readAll());
