@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "createresource.h"
@@ -94,7 +82,7 @@ QString CreateResource::createResource(const QString &resources, const QString &
     }
 
     Q_EMIT createResourceInfo(i18n("Creating resource instance for '%1'...", type.name()));
-    AgentInstanceCreateJob *job = new AgentInstanceCreateJob(type, this);
+    auto *job = new AgentInstanceCreateJob(type, this);
     if (job->exec()) {
         Akonadi::AgentInstance instance = job->instance();
 
